darkhistory.electrons.ics.ics_spectrum — DarkHistory documentation

# darkhistory.electrons.ics.ics_spectrum

Inverse Compton scattering spectrum after integrating over CMB.

Functions

`ics_spec`(eleckineng, photeng, T[, as_pairs, …]) | ICS spectrum of secondary photons.
`thomson_spec_series`(eleckineng, photeng, T) | Thomson ICS spectrum of secondary photons by series method.
`thomson_spec_diff`(eleckineng, photeng, T[, …]) | Thomson ICS spectrum of secondary photons by beta expansion.
`thomson_spec`(eleckineng, photeng, T[, as_pairs]) | Thomson ICS spectrum of secondary photons.
`thomson_spec_quad`(eleckineng_arr, photeng_arr, T) | Thomson ICS spectrum of secondary photons using quadrature.
`rel_spec`(eleceng, photeng, T[, …]) | Relativistic ICS spectrum of secondary photons.

#### Previous topic

darkhistory.electrons.ics.ics_engloss_spectrum.engloss_spec_series

#### Next topic

darkhistory.electrons.ics.ics_spectrum.ics_spec

### This Page

Show Source